'use strict'

exports.default = cloneDeep

/**
 * Deeply clones the given value.
 *
 * @param value - The value to clone
 * @returns Deep clone of the given value
 *
 * @category Common
 * @public
 */
function cloneDeep(value) {
  if (!value || !(typeof value === 'object')) return value
  if (value instanceof Date) return new Date(value)
  var newObj = Array.isArray(value) ? [] : {}
  var valueObj = value
  Object.keys(valueObj).forEach(function (key) {
    if (valueObj[key] && typeof valueObj[key] === 'object') {
      newObj[key] = cloneDeep(valueObj[key])
    } else {
      newObj[key] = valueObj[key]
    }
  })
  return newObj
}
