'use strict'

exports.default = debounce

/**
 * Creates a function that will execute after the given timeout after the last call.
 *
 * @param fn - The function to execute
 * @param wait - The timeout
 * @returns A function based on the provided function that will execute after the given timeout after the last call
 *
 * @category Function
 * @public
 */
function debounce(fn, wait) {
  var timeout
  return function () {
    for (
      var _len = arguments.length, args = new Array(_len), _key = 0;
      _key < _len;
      _key++
    ) {
      args[_key] = arguments[_key]
    }

    clearTimeout(timeout)
    timeout = setTimeout(function () {
      fn.apply(void 0, args)
    }, wait)
  }
}
