'use strict'

exports.default = map

/**
 * Maps through entries of the given object and returns values by the given key.
 *
 * @param object - The object to map
 * @param key - The key to map with
 * @returns The values by the given key
 *
 * @category Collection
 * @public
 */

/**
 * Maps through entries of the given object and collects values returned from the mapper function.
 *
 * @param object - The object to map
 * @param mapper - The mapper function
 * @returns The values returned from the mapper function
 *
 * @category Collection
 * @public
 */

/**
 * Maps through elements of the given array and returns values by the given key.
 *
 * @param array - The array to map
 * @param key - The key to map with
 * @returns The values by the given key
 *
 * @category Collection
 * @public
 */

/**
 * Maps through elements of the given array and collects values returned from the mapper function.
 *
 * @param array - The array to map
 * @param mapper - The mapper function
 * @returns The values returned from the mapper function
 *
 * @category Collection
 * @public
 */

/**
 * @internal
 */
function map(array, mapper) {
  if (Array.isArray(array)) {
    if (typeof mapper === 'string') {
      return array.map(function (element) {
        return element[mapper]
      })
    } else {
      return array.map(mapper)
    }
  } else {
    var keys = Object.keys(array)
    return keys.map(function (key) {
      if (typeof mapper === 'string') {
        return array[key][mapper]
      } else {
        return mapper(array[key], key)
      }
    })
  }
}
