'use strict'

exports.default = pick

/**
 * Picks the given fields from the provided object.
 *
 * @param object - The object to pick fields from
 * @param keys - The array of field names to pick
 * @returns An object with the given fields picked
 *
 * @category Object
 * @public
 */
function pick(object, keys) {
  return (Array.isArray(keys) ? keys : [keys]).reduce(function (result, key) {
    if (key in object) {
      result[key] = object[key]
    }

    return result // NOTE: Figure out why when we use ReturnType instead of the type below,
    // it shows a type error.
  }, {})
}
