'use strict'

exports.default = reduce

/**
 * Accumulates entries of the given object.
 *
 * @param object - The object to reduce
 * @param reducer - The reducer function
 * @param initialValue - The initial accumulator value
 * @returns The accumulated value
 *
 * @category Collection
 * @public
 */

/**
 * Accumulates elements of the given array.
 *
 * @param array - The array to reduce
 * @param reducer - The reducer function
 * @param initialValue - The initial accumulator value
 * @returns The accumulated value
 *
 * @category Collection
 * @public
 */

/**
 * @internal
 */
function reduce(object, reducer, initialValue) {
  if (Array.isArray(object)) {
    return object.reduce(reducer, initialValue)
  } else {
    var keys = Object.keys(object)
    return keys.reduce(function (acc, key) {
      return reducer(acc, object[key], key)
    }, initialValue)
  }
}
