'use strict'

exports.default = throttle

/**
 * Creates a function that execute no more than once per the given timeout.
 *
 * @param fn - The function to execute
 * @param wait - The timeout
 * @returns A function based on the provided function that execute no more than once per the given timeout
 *
 * @category Function
 * @public
 */
function throttle(fn, wait) {
  var timeout
  return function () {
    if (timeout === undefined) {
      fn.apply(void 0, arguments)
      timeout = setTimeout(function () {
        timeout = undefined
      }, wait)
    }
  }
}
