'use strict'

exports.default = uniq

/**
 * Creates an array with unique elements from the given array.
 *
 * @param array - The array to pick unique elements from
 * @returns An array with unique elements from the given array
 *
 * @public
 */

/**
 * Creates an array with unique elements from the given array which uniqueness is determined using the mapper function.
 *
 * @param array - The array to pick unique elements from
 * @param mapper - The function that returns the value to check for uniqueness
 *
 * @public
 */

/**
 * Creates an array with unique elements from the given array which uniqueness is determined by the element field
 *
 * @param array - The array to pick unique elements from
 * @param key - The name of the field to check for uniqueness
 *
 * @public
 */

/**
 * @category Array
 * @internal
 */
function uniq(array, mapper) {
  var set = new Set()
  var result = []

  for (var _i = 0; _i < array.length; _i++) {
    var element = array[_i]

    var _key =
      typeof mapper === 'function'
        ? mapper(element)
        : mapper
        ? element[mapper]
        : element

    if (!set.has(_key)) {
      set.add(_key)
      result.push(element)
    }
  }

  return result
}
